==> openGion_dev_5.5.3.0.zip: opengion/uap/webapps/gf/src/org/opengion/plugin/query/DBConstValue_VV.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.query;

import org.opengion.hayabusa.common.HybsSystem;
import org.opengion.hayabusa.db.DBConstValue;

/**
 * データベース登録時に、固定値カラムの設定を行う情報を管理するクラスです。
 * このクラスは、GrowingMIS Ver6用の管理クラスです。
 * 具体的には、
 *     物理SEQ     SEQxxxx   (xxxxはテーブル名)
 *     作成日時    DYSET
 *     作成ＰＧ    PGSET
 *     作成親ＰＧ  PGPSET
 *     作成社員    USRSET
 *     更新日時    DYUPD
 *     更新ＰＧ    PGUPD
 *     更新親ＰＧ  PGPUPD
 *     更新社員    USRUPD
 * などの情報を、INSERT、UPDATE の状況に応じて提供します。
 * INSERT には、すべての情報(XXUPD)にも値をセットします。
 * これは、UPDATE された日付や時刻で、一覧検索できるようにする為で、
 * null にしておくと、IS NULL で問い合わせる必要があります。
 * INSERT データだけ取出す場合は、WHERE DYSET = DYUPD とします。
 * また、 物理SEQは、SEQxxxx(xxxxはテーブル名)形式のカラム名とし、
 * 値は、SEQxxxxS01.NEXTVAL とします。
 *
 * コンストラクターでは、テーブル名、ユーザーID,画面ID を受け取ります。
 * 登録時刻は、このオブジェクトが生成された時間を通常は使用します。
 * テーブル名を渡すのは、ワークなど、テーブル単位に処理するカラムが
 * 異なるので、それへの対応です。
 * 処理が簡素化できるように、ルールを規定すべきです。
 *
 * @og.rev 5.5.1.8 (2012/04/17) 新規追加
 * @og.group データ登録
 *
 * @version  5.5
 * @author   Kazuhiko Hasegawa
 * @since    JDK7.0,
 */
public class DBConstValue_VV implements DBConstValue {
//	private static final String[] MSTR_INSKEYS = 
//		new String[] { "DYSET","PGSET","PGPSET","USRSET","DYUPD","PGUPD","PGPUPD","USRUPD" };

	private static final String[] MSTR_UPDKEYS = 
		new String[] { "DYUPD","PGUPD","PGPUPD","USRUPD" };

	private static final String[] ZERO = new String[0] ;

	private String[] insKeys = ZERO;
	private String[] insVals = ZERO;

	private String[] updKeys = ZERO;
	private String[] updVals = ZERO;

	/**
	 * 初期化情報を設定します。
	 *
	 * @param  table String テーブル名
	 * @param  user  String ユーザーID
	 * @param  gamen String 画面ID
	 */
	public void init( final String table, final String user, final String gamen ) {
		if( isUseClm( table ) ) {
			String userID  = "'" + user + "'";
			String gamenID = "'" + gamen + "'";
			String timestamp = "'" + HybsSystem.getDate( "yyyyMMddHHmmss" ) + "'" ;
			String seqID   = "SEQ" + table ;
			String seqFanc = "SEQ" + table + "S01.NEXTVAL" ;

//			insKeys = MSTR_INSKEYS;
			insKeys = new String[] { seqID, "DYSET","PGSET","PGPSET","USRSET","DYUPD","PGUPD","PGPUPD","USRUPD" };
			insVals = new String[] {
							 seqFanc		// SEQ領域の関数
							,timestamp		// DYSET
							,gamenID		// PGSET
							,gamenID		// PGPSET
							,userID			// USRSET
							,timestamp		// DYUPD
							,gamenID		// PGUPD
							,gamenID		// PGPUPD
							,userID			// USRUPD
			};

			updKeys = MSTR_UPDKEYS;
			updVals = new String[] {
							 timestamp		// DYUPD
							,gamenID		// PGUPD
							,gamenID		// PGPUPD
							,userID			// USRUPD
			};
		}
	}

	/**
	 * INSERT する場合のキー配列を返します。
	 *
	 * 指定の値がなければ、長さゼロ配列を返します。
	 *
	 * @return  String[]  (非null)
	 */
	public String[] getInsertKeys() {
		return insKeys.clone();
	}

	/**
	 * INSERT する場合の値配列を返します。
	 *
	 * 指定の値がなければ、長さゼロ配列を返します。
	 *
	 * @return  String[] (非null)
	 */
	public String[] getInsertVals() {
		return insVals.clone();
	}

	/**
	 * UPDATE する場合のキー配列を返します。
	 *
	 * 指定の値がなければ、長さゼロ配列を返します。
	 *
	 * @return  String[] (非null)
	 */
	public String[] getUpdateKeys() {
		return updKeys.clone();
	}

	/**
	 * UPDATE する場合の値配列を返します。
	 *
	 * 指定の値がなければ、長さゼロ配列を返します。
	 *
	 * @return  String[] (非null)
	 */
	public String[] getUpdateVals() {
		return updVals.clone();
	}

	/**
	 * DELETE(論理削除) する場合のキー配列を返します。
	 *
	 * 指定の値がなければ、長さゼロ配列を返します。
	 *
	 * @return  String[] (非null)
	 */
	public String[] getLogicalDeleteKeys() {
		return ZERO;
	}

	/**
	 * DELETE(論理削除) する場合の値配列を返します。
	 *
	 * 指定の値がなければ、長さゼロ配列を返します。
	 *
	 * @return  String[] (非null)
	 */
	public String[] getLogicalDeleteVals() {
		return ZERO;
	}

	/**
	 * カラムを返すかどうかを決めるロジック
	 *
	 * テーブル名が存在していれば、利用可能と判断します。
	 * これは、履歴テーブルなど、この処理を使わない場合に、
	 * テーブル名から判定する場合に使います。現時点では、履歴テーブルは
	 * フレームワーク側で変更するのではなく、トリガ等による自動収集と
	 * しますので、判定対象としていません。
	 *
	 * @return  boolean (true:カラムを生成/false:カラムは生成しない)
	 */
	private boolean isUseClm( final String table ) {
		boolean flag = ( table != null && table.length() > 0 ) ;

		return flag ;
	}
}

==> openGion_dev_5.5.6.1.zip: opengion/uap/webapps/gf/src/org/opengion/plugin/query/DBConstValue_VV.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.query;

import org.opengion.hayabusa.common.HybsSystem;
import org.opengion.hayabusa.db.DBConstValue;

/**
 * データベース登録時に、固定値カラムの設定を行う情報を管理するクラスです。
 * このクラスは、GrowingMIS Ver6用の管理クラスです。
 * 具体的には、
 *     物理SEQ     SEQxxxx   (xxxxはテーブル名)
 *     作成日時    DYSET
 *     作成ＰＧ    PGSET
 *     作成親ＰＧ  PGPSET
 *     作成社員    USRSET
 *     更新日時    DYUPD
 *     更新ＰＧ    PGUPD
 *     更新親ＰＧ  PGPUPD
 *     更新社員    USRUPD
 * などの情報を、INSERT、UPDATE の状況に応じて提供します。
 * INSERT には、すべての情報(XXUPD)にも値をセットします。
 * これは、UPDATE された日付や時刻で、一覧検索できるようにする為で、
 * null にしておくと、IS NULL で問い合わせる必要があります。
 * INSERT データだけ取出す場合は、WHERE DYSET = DYUPD とします。
 * また、 物理SEQは、SEQxxxx(xxxxはテーブル名)形式のカラム名とし、
 * 値は、SEQxxxxS01.NEXTVAL とします。
 *
 * コンストラクターでは、テーブル名、ユーザーID,画面ID を受け取ります。
 * 登録時刻は、このオブジェクトが生成された時間を通常は使用します。
 * テーブル名を渡すのは、ワークなど、テーブル単位に処理するカラムが
 * 異なるので、それへの対応です。
 * 処理が簡素化できるように、ルールを規定すべきです。
 *
 * @og.rev 5.5.1.8 (2012/04/17) 新規追加
 * @og.group データ登録
 *
 * @version  5.5
 * @author   Kazuhiko Hasegawa
 * @since    JDK7.0,
 */
public class DBConstValue_VV implements DBConstValue {
//	private static final String[] MSTR_INSKEYS =
//		new String[] { "DYSET","PGSET","PGPSET","USRSET","DYUPD","PGUPD","PGPUPD","USRUPD" };

	private static final String[] MSTR_UPDKEYS =
		new String[] { "DYUPD","PGUPD","PGPUPD","USRUPD" };

	private static final String[] ZERO = new String[0] ;

	private String[] insKeys = ZERO;
	private String[] insVals = ZERO;

	private String[] updKeys = ZERO;
	private String[] updVals = ZERO;

	/**
	 * 初期化情報を設定します。
	 *
	 * @param	table	テーブル名
	 * @param	user 	ユーザーID
	 * @param	gamen	画面ID
	 */
	public void init( final String table, final String user, final String gamen ) {
		if( isUseClm( table ) ) {
			String userID  = "'" + user + "'";
			String gamenID = "'" + gamen + "'";
			String timestamp = "'" + HybsSystem.getDate( "yyyyMMddHHmmss" ) + "'" ;
			String seqID   = "SEQ" + table ;
			String seqFanc = "SEQ" + table + "S01.NEXTVAL" ;

//			insKeys = MSTR_INSKEYS;
			insKeys = new String[] { seqID, "DYSET","PGSET","PGPSET","USRSET","DYUPD","PGUPD","PGPUPD","USRUPD" };
			insVals = new String[] {
							 seqFanc		// SEQ領域の関数
							,timestamp		// DYSET
							,gamenID		// PGSET
							,gamenID		// PGPSET
							,userID			// USRSET
							,timestamp		// DYUPD
							,gamenID		// PGUPD
							,gamenID		// PGPUPD
							,userID			// USRUPD
			};

			updKeys = MSTR_UPDKEYS;
			updVals = new String[] {
							 timestamp		// DYUPD
							,gamenID		// PGUPD
							,gamenID		// PGPUPD
							,userID			// USRUPD
			};
		}
	}

	/**
	 * インサートする場合のキー配列を返します。
	 *
	 * 指定の値がなければ、長さゼロ配列を返します。
	 *
	 * @return	インサートする場合のキー配列(非null)
	 */
	public String[] getInsertKeys() {
		return insKeys.clone();
	}

	/**
	 * インサートする場合の値配列を返します。
	 *
	 * 指定の値がなければ、長さゼロ配列を返します。
	 *
	 * @return	インサートする場合のキー配列(非null)
	 */
	public String[] getInsertVals() {
		return insVals.clone();
	}

	/**
	 * アップデートする場合のキー配列を返します。
	 *
	 * 指定の値がなければ、長さゼロ配列を返します。
	 *
	 * @return	アップデートする場合のキー配列(非null)
	 */
	public String[] getUpdateKeys() {
		return updKeys.clone();
	}

	/**
	 * アップデートする場合の値配列を返します。
	 *
	 * 指定の値がなければ、長さゼロ配列を返します。
	 *
	 * @return	アップデートする場合のキー配列(非null)
	 */
	public String[] getUpdateVals() {
		return updVals.clone();
	}

	/**
	 * デリート(論理削除) する場合のキー配列を返します。
	 *
	 * 指定の値がなければ、長さゼロ配列を返します。
	 *
	 * @return	デリートする場合のキー配列(非null)
	 */
	public String[] getLogicalDeleteKeys() {
		return ZERO;
	}

	/**
	 * デリート(論理削除) する場合の値配列を返します。
	 *
	 * 指定の値がなければ、長さゼロ配列を返します。
	 *
	 * @return	デリートする場合のキー配列(非null)
	 */
	public String[] getLogicalDeleteVals() {
		return ZERO;
	}

	/**
	 * カラムを返すかどうかを決めるロジック
	 *
	 * テーブル名が存在していれば、利用可能と判断します。
	 * これは、履歴テーブルなど、この処理を使わない場合に、
	 * テーブル名から判定する場合に使います。現時点では、履歴テーブルは
	 * フレームワーク側で変更するのではなく、トリガ等による自動収集と
	 * しますので、判定対象としていません。
	 *
	 * @param	table	テーブル名
	 *
	 * @return	カラムを返すかどうか(true:カラムを生成/false:カラムは生成しない)
	 */
	private boolean isUseClm( final String table ) {
		boolean flag = ( table != null && table.length() > 0 ) ;

		return flag ;
	}
}
